@@ -3,6 +3,7 @@
 
 from wsgiref.util import shift_path_info
 import cgi
+import sys
     
 global __request__handlers__
 __request__handlers__ = {}
@@ -11,54 +12,22 @@ def route(path):
     """
     Decorates a function for handling page requests to
     a certain path
-    
-    >>> from pyroutes import route
-    >>> @route('/')
-    ... def foo():
-    ...     pass
-    ... 
-    >>> from pyroutes import __request__handlers__
-    >>> '/' in __request__handlers__
-    True
-    
     """
     global __request__handlers__
     
     def decorator(func):
         if path in __request__handlers__:
-            print "Warning: Redefining handler for %s with %s" % (path, func)
+            raise ValueError("Tried to redefine handler for %s with %s" % (path, func))
         __request__handlers__[path] = func
     return decorator
 
-class Request:
-    """
-    A basic request class wrapping WSGI-environment
-    in a more friendly matter
-    """
-    
-    def __init__(self, environ):
-        self.environ = environ
-        self.request_path = "/" + "/".join(create_request_path(environ))
-        self.GET = {}
-        self.POST = {}
-        if environ.get('REQUEST_METHOD', None) == 'POST':
-            pass
-        else:
-            pass
-
 def create_request_path(environ):
     """
     Returns a tuple consisting of the individual request parts
-    
-    >>> from pyroutes import create_request_path
-    >>> create_request_path({'PATH_INFO': '/foo/bar'})
-    ['foo', 'bar']
-    >>> create_request_path({'PATH_INFO': '/'})
-    ['/']
     """
     handlers = __request__handlers__.keys()
     path = shift_path_info(environ)
-    request = [] 
+    request = []
     if not path:
         request = ['/']
     else:
@@ -66,20 +35,10 @@ def create_request_path(environ):
             request.append(path)
             path = shift_path_info(environ)
     return request
-    
+
 def find_request_handler(current_path):
     """
     Locates the handler for the specified path. Return None if not found.
-    
-    >>> from pyroutes import route, find_request_handler
-    >>> @route('/')
-    ... def foo():
-    ...     pass
-    ...
-    >>> find_request_handler('/') != None
-    True
-    >>> find_request_handler('/foo') == None
-    True
     """
     handler = None
     while handler is None:
@@ -120,12 +79,11 @@ def application(environ, start_response):
     try:
         data = create_data_dict(environ)
         response = handler(environ, data)
+        if 'Content-Length' not in [a[0] for a in response.headers]:
+            response.headers.append(('Content-Length', str(sys.getsizeof(response.content))))
         start_response(response.status_code, response.headers)
-        return[response.content]
+        return [response.content]
     except Exception, exception:
         start_response('500 Error', [('Content-type', 'text/plain')])
         return ["An error occurred\n%s" % str(exception)]
 
-if __name__ == '__main__':
-    import doctest
-    doctest.testmod()
